/*
 * prefs.h -- Alarm Clock global preferences
 * 
 * Copyright (C) 2007-2008 Johannes H. Jensen <joh@pseudoberries.com>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Authors:
 * 		Johannes H. Jensen <joh@pseudoberries.com>
 */

#ifndef PREFS_H_
#define PREFS_H_

#include "alarm-applet.h"

void
prefs_init (AlarmApplet *applet);

void
prefs_dialog_show (AlarmApplet *applet);

gboolean
prefs_autostart_get_state (void);

void
prefs_autostart_set_state (gboolean state);

gboolean
prefs_show_label_get (AlarmApplet *applet);

void
prefs_show_label_set (AlarmApplet *applet, gboolean state);

#endif /*PREFS_H_*/
